@@ -6,6 +6,23 @@
 //!
 //! Unlike e.g. the AWS Java SDK this library does not download
 //! the parts as uploaded but ranges.
+//!
+//! ```rust, noexec
+//!
+//! use condow_rusoto::*;
+//! use condow_rusoto::config::Config;
+//!
+//! # async {
+//! let client = S3ClientWrapper::new(Default::default());
+//! let condow = client.condow(Config::default()).unwrap();
+//!
+//! let location = Bucket::new("my_bucket").object("my_object");
+//!
+//! let stream = condow.download(location, 23..46).await.unwrap();
+//! let downloaded_bytes: Vec<u8> = stream.into_vec().await.unwrap();
+//! # };
+//! # ()
+//! ```
 use std::{
     fmt,
     ops::{Deref, DerefMut},
@@ -51,6 +68,12 @@ impl fmt::Display for Bucket {
     }
 }
 
+impl From<&str> for Bucket {
+    fn from(s: &str) -> Self {
+        Self::new(s)
+    }
+}
+
 impl Deref for Bucket {
     type Target = str;
 
@@ -103,6 +126,12 @@ impl DerefMut for ObjectKey {
     }
 }
 
+impl From<&str> for ObjectKey {
+    fn from(s: &str) -> Self {
+        Self::new(s)
+    }
+}
+
 /// Full "path" to an S3 object
 #[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub struct S3Location(Bucket, ObjectKey);
